@@ -1,15 +1,14 @@
 """html2text: Turn HTML into equivalent Markdown-structured text."""
-__version__ = "2.2"
+__version__ = "2.23"
 __author__ = "Aaron Swartz (me@aaronsw.com)"
 __copyright__ = "(C) 2004 Aaron Swartz. GNU GPL 2."
-__contributors__ = ["Martin 'Joey' Schulze"]
+__contributors__ = ["Martin 'Joey' Schulze", "Ricardo Reyes"]
 
 # TODO:
 #   Support decoded entities with unifiable.
-#	Word wrap. 
-#	Fix :s using buffering
-#	Relative URl resolution
+#	Relative URL resolution
 
+if not hasattr(__builtins__, 'True'): True, False = 1, 0
 import re, sys, urllib, htmlentitydefs, codecs, StringIO, types
 import sgmllib
 sgmllib.charref = re.compile('&#([xX]?[0-9a-fA-F]+)[^0-9a-fA-F]')
@@ -190,7 +189,7 @@ class _html2text(sgmllib.SGMLParser):
  			if a.has_key('href') and a['href'] == attrs['href']:
  				if a.has_key('title') or attrs.has_key('title'):
  						if (a.has_key('title') and attrs.has_key('title') and
- 						    a['title'] == attrs['title']):
+						    a['title'] == attrs['title']):
  							match = True
  				else:
  					match = True
@@ -276,7 +275,7 @@ class _html2text(sgmllib.SGMLParser):
 			if start:
 				self.list.append({'name':tag, 'num':0})
 			else:
-				self.list.pop()
+				if self.list: self.list.pop()
 			
 			self.p()
 		
@@ -309,7 +308,6 @@ class _html2text(sgmllib.SGMLParser):
 
 	def p(self): self.p_p = 2
 	
-	
 	def o(self, data, puredata=0, force=0):
 		if not self.quiet: 
 			if puredata and not self.pre:
@@ -320,7 +318,7 @@ class _html2text(sgmllib.SGMLParser):
 			if not data and not force: return
 			
 			if self.startpre:
-				self.out(" :") #TODO: not output when already one there
+				#self.out(" :") #TODO: not output when already one there
 				self.startpre = 0
 			
 			bq = (">" * self.blockquote)
@@ -356,7 +354,7 @@ class _html2text(sgmllib.SGMLParser):
 				newa = []
 				for link in self.a:
 					if self.outcount > link['outcount']:
-						self.out("    ["+`link['count']`+"]: " + link['href']) #TODO: base href
+						self.out("   ["+`link['count']`+"]: " + link['href']) #TODO: base href
 						if link.has_key('title'): self.out(" ("+link['title']+")")
 						self.out("\n")
 					else:
@@ -395,3 +393,4 @@ if __name__ == "__main__":
 	else:
 		data = sys.stdin.read()
 	html2text_file(data)
+
